package main;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.HeadlessException;
import java.awt.Rectangle;
import java.awt.Robot;
import java.awt.image.BufferedImage;
import java.io.File;

import javax.imageio.ImageIO;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;

import main.listener.ListenerDeEventosNativos;
import main.listener.ProcessadorDeEventosNativos;

public class Main {

	private static BufferedImage checkBoxImage;
	private static JFrame tela;
	private static Robot robo;

	private static BuscadorDaCheckboxDaLinhaSelecionada buscadorDaCheckboxDaLinhaSelecionada;

	public static void main(String[] args) {

		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				try {
					tela = new Tela();
				} catch (Exception e) {
					e.printStackTrace();
					saidaComErro(e);
				}
			}
		});

		try {
			ListenerDeEventosNativos.iniciar();
			iniciarConfiguracoes();
			Clicador clicador = new Clicador(robo, buscadorDaCheckboxDaLinhaSelecionada);
			ListenerDeEventosNativos
					.addNativeKeyListener(new ProcessadorDeEventosNativos(clicador::clicarNaCheckbox, () -> {
						SwingUtilities.invokeLater(() -> tela.repaint());
					}));
		} catch (Exception e1) {
			e1.printStackTrace();
			saidaComErro(e1);
		}
	}

	/** Altere as configuraes para corresponder as suas necessidades. */
	private static void iniciarConfiguracoes() throws Exception {
		robo = new Robot();
		checkBoxImage = ImageIO.read(new File("src/images/partedecheckbox.png"));
		BuscadorDeLinhaSelecionada buscadorDeLinhaSelecionada = new BuscadorDeLinhaSelecionada(new Color(255, 150, 50),
				5, 5);
		Rectangle areaDaSelecao = new Rectangle(674, 318, 103, 492);
		buscadorDaCheckboxDaLinhaSelecionada = new BuscadorDaCheckboxDaLinhaSelecionada(checkBoxImage,
				buscadorDeLinhaSelecionada, areaDaSelecao, 365, 400);
	}

	private static void saidaComErro(Exception e) throws HeadlessException {
		JOptionPane.showMessageDialog(null, e);
		System.exit(1);
	}

	@SuppressWarnings("serial")
	private static class Tela extends JFrame {

		Tela() {
			super("Clicador em Checkbox de linha Selecionada");
			System.out.println("creating instance");
			setSize(230, 500);
			setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
			add(new Painel());
			setAlwaysOnTop(true);
			setVisible(true);
		}
	}

	@SuppressWarnings("serial")
	private static class Painel extends JPanel {
		@Override
		protected void paintComponent(Graphics g) {
			super.paintComponent(g);
			g.setColor(Color.DARK_GRAY);
			g.fillRect(0, 0, getWidth(), getHeight());

			BufferedImage areaDaSelecao = buscadorDaCheckboxDaLinhaSelecionada.areaDaSelecaoBuscada.get();
			if (areaDaSelecao != null) {
				g.drawImage(areaDaSelecao, 20, 20, null);
				BufferedImage areaDaCheckbox = buscadorDaCheckboxDaLinhaSelecionada.areaComCheckboxBuscada.get();
				if (areaDaCheckbox != null) {
					g.drawImage(areaDaCheckbox, areaDaSelecao.getWidth() + 30, 20, null);
					g.drawImage(checkBoxImage, areaDaSelecao.getWidth() + 30, areaDaCheckbox.getHeight() + 30, null);
				}
			}
		}

	}

}
